==> seedsui-react-5.7.30.tgz: package/lib/Location/Main/utils/addMarkers.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import gcjToBdPoint from "./gcjToBdPoint";
import pointToBdPoint from "./pointToBdPoint";
import getMarkerIcon from "./getMarkerIcon";

// 添加点
function addMarkers(points, _ref) {
  var map = _ref.map,
    type = _ref.type,
    color = _ref.color,
    zIndex = _ref.zIndex;
  var markers = [];
  var _iterator = _createForOfIteratorHelper(points),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var poi = _step.value;
      if (type === 'gcj02') {
        poi = gcjToBdPoint(poi);
      } else {
        poi = pointToBdPoint(poi);
      }
      var icon = getMarkerIcon(color);
      var marker = new BMap.Marker(poi, {
        icon: icon
      });
      if (zIndex) {
        marker.setZIndex(zIndex);
      }
      map.addOverlay(marker);
      markers.push(marker);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return markers;
}
export default addMarkers;

==> seedsui-react-5.7.93.tgz: package/lib/Location/Main/utils/addMarkers.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import gcjToBdPoint from "./gcjToBdPoint";
import pointToBdPoint from "./pointToBdPoint";
import getMarkerIcon from "./getMarkerIcon";

// 添加点
function addMarkers(points, _ref) {
  var map = _ref.map,
    type = _ref.type,
    color = _ref.color,
    zIndex = _ref.zIndex;
  var markers = [];
  var _iterator = _createForOfIteratorHelper(points),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var poi = _step.value;
      if (type === 'gcj02') {
        poi = gcjToBdPoint(poi);
      } else {
        poi = pointToBdPoint(poi);
      }
      var icon = getMarkerIcon(color, map === null || map === void 0 ? void 0 : map.markerConfig);
      var marker = new window.BMap.Marker(poi, {
        icon: icon
      });
      if (zIndex) {
        marker.setZIndex(zIndex);
      }
      map.addOverlay(marker);
      markers.push(marker);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return markers;
}
export default addMarkers;
